.. _variables_style_rules:

Variables and Symbols
=====================

There is a convention on consistent variable names throughout the library:

.. csv-table:: List of used Variables and Parameters
   :file: ../../../pvlib/data/variables_style_rules.csv
   :delim: ;
   :header-rows: 1
   :widths: 5, 5
   :stub-columns: 1
   
For a definition and further explanation on the variables, common symbols and units refer to the following sources:


* `Reference Variable List by PVPMC <https://pvpmc.sandia.gov/resources-and-events/variable-list/>`_
* `IEC 61724-1:2017  -- Photovoltaic system performance - Part 1: Monitoring  <https://webstore.iec.ch/publication/33622>`_ section: 3 -- Terms and definitions; the Indian Standard referencing the withdrawn earlier global IEC standard IEC 61724:1998 is available online: `IS/IEC 61724 (1998) <https://archive.org/details/gov.in.is.iec.61724.1998>`_ and can provide relevant contents.
* Explanation of Solar irradiation and solar geometry by `SoDa Service <http://www.soda-pro.com/home>`_
  
   * `Acronyms, Terminology and Units <http://www.soda-pro.com/help/general/acronyms-terminology-and-units>`_
   * `Plane orientations and radiation components <http://www.soda-pro.com/help/general/plane-orientations-and-radiation-components>`_
   * `Time references <http://www.soda-pro.com/help/general/time-references>`_
   * `Units and conversion tool <http://www.soda-is.com/eng/education/units.html>`_
   * `Terminology: definitions of the main quantities. <http://www.soda-is.com/eng/education/terminology.html>`_
   * `Acronyms in solar radiation <http://www.soda-is.com/eng/education/acronymes.html>`_ (more extensive list)

.. note:: These further references might not use the same terminology as *pvlib*. But the physical process referred to is the same.
